=== modified file 'configure.ac'
--- configure.ac	2009-03-24 04:59:05 +0000
+++ configure.ac	2009-03-30 18:35:28 +0000
@@ -261,8 +261,12 @@
   then
     IS_64="-m64"
   fi
-  LDFLAGS="${LDFLAGS} -L/usr/local/lib/${isainfo_b} -L/usr/local/lib -L/opt/csw/lib/${isainfo_b} -L/opt/csw/lib -L/usr/lib/${isainfo_b}"
-  CPPFLAGS="${CPPFLAGS} -I/usr/local/include -I/opt/csw/include"
+  if test "x$use_additional" != "xyes"
+  then
+    LDFLAGS="${LDFLAGS} -L/usr/local/lib/${isainfo_b} -L/usr/local/lib -L/opt/csw/lib/${isainfo_b} -L/opt/csw/lib"
+    CPPFLAGS="${CPPFLAGS} -I/usr/local/include -I/opt/csw/include"
+  fi
+  LDFLAGS="${LDFLAGS} -L/usr/lib/${isainfo_b}"
 
   CXXFLAGS="-xlang=c99 -g -mt -compat=5 -library=stlport4 -template=no%extdef ${IS_64} ${MEMALIGN_FLAGS} ${CXXFLAGS}"
   CFLAGS="-g -mt -xc99=all ${IS_64} ${MEMALIGN_FLAGS} ${CFLAGS}"
@@ -862,6 +866,10 @@
 then
   AC_MSG_ERROR("Drizzle needs a off_t type.")
 fi
+AC_CHECK_SIZEOF(size_t)
+AC_DEFINE_UNQUOTED([SIZEOF_SIZE_T],[$ac_cv_sizeof_size_t],[Size of size_t as computed by sizeof()])
+AC_CHECK_SIZEOF(long long)
+AC_DEFINE_UNQUOTED(SIZEOF_LONG_LONG,[$ac_cv_sizeof_long_long],[Size of long long as computed by sizeof()])
 
 dnl
 dnl check if time_t is unsigned

=== modified file 'drizzled/atomic/gcc_traits.h'
--- drizzled/atomic/gcc_traits.h	2009-03-04 02:48:12 +0000
+++ drizzled/atomic/gcc_traits.h	2009-03-30 18:17:18 +0000
@@ -20,7 +20,7 @@
 #ifndef DRIZZLED_ATOMIC_GCC_TRAITS_H
 #define DRIZZLED_ATOMIC_GCC_TRAITS_H
 
-namespace tbb {
+namespace drizzled {
 namespace internal {
 
 template<typename T, typename D>
@@ -80,6 +80,6 @@
 
 
 } /* namespace internal */
-} /* namespace tbb */
+} /* namespace drizzled */
 
 #endif /* DRIZZLED_ATOMIC_GCC_TRAITS_H */

=== modified file 'drizzled/atomic/pthread_traits.h'
--- drizzled/atomic/pthread_traits.h	2009-03-04 02:48:12 +0000
+++ drizzled/atomic/pthread_traits.h	2009-03-30 18:17:18 +0000
@@ -21,7 +21,7 @@
 #ifndef DRIZZLED_ATOMIC_PTHREAD_TRAITS_H
 #define DRIZZLED_ATOMIC_PTHREAD_TRAITS_H
 
-namespace tbb {
+namespace drizzled {
 
 namespace internal {
 
@@ -133,7 +133,7 @@
 
 
 } /* namespace internal */
-} /* namespace tbb */
+} /* namespace drizzled */
 
 
 #endif /* DRIZZLED_ATOMIC_PTHREAD_TRAITS_H */

=== modified file 'drizzled/atomics.h'
--- drizzled/atomics.h	2009-03-04 02:48:12 +0000
+++ drizzled/atomics.h	2009-03-30 18:37:43 +0000
@@ -23,6 +23,13 @@
 
 #if defined(HAVE_LIBTBB)
 # include <tbb/atomic.h>
+/* We're actually using the TBB interface directly, but we don't want to tie
+ * the code to a specific implementation. So suck the tbb:: stuff into the
+ * drizzled namespace
+ */
+namespace drizzled {
+  using namespace tbb;
+}
 #else
 
 # if defined(__SUNPRO_CC)
@@ -32,13 +39,16 @@
 #  include <drizzled/atomic/gcc_traits.h>
 #  define ATOMIC_TRAITS internal::gcc_traits
 # else  /* use pthread impl */
+#  define ATOMIC_TRAITS internal::pthread_traits
+# endif
+
+# if (SIZEOF_SIZE_T >= SIZEOF_LONG_LONG) || (!defined(HAVE_GCC_ATOMIC_BUILTINS) || !defined(__SUNPRO_CC))
 #  include <pthread.h>
 #  include <drizzled/atomic/pthread_traits.h>
-#  define ATOMIC_TRAITS internal::pthread_traits
 # endif
 
 
-namespace tbb {
+namespace drizzled {
 
 namespace internal {
 
@@ -137,26 +147,44 @@
 struct atomic {
 };
 
-#define __TBB_DECL_ATOMIC(T)                                            \
+#define __DRIZZLE_DECL_ATOMIC(T)                                        \
   template<> struct atomic<T>                                           \
   : internal::atomic_impl<T,T,ATOMIC_TRAITS<T,T> > {                    \
     atomic<T>() : internal::atomic_impl<T,T,ATOMIC_TRAITS<T,T> >() {}   \
     T operator=( T rhs ) { return store_with_release(rhs); }            \
   };
 
-__TBB_DECL_ATOMIC(long long)
-__TBB_DECL_ATOMIC(unsigned long long)
-__TBB_DECL_ATOMIC(long)
-__TBB_DECL_ATOMIC(unsigned long)
-__TBB_DECL_ATOMIC(unsigned int)
-__TBB_DECL_ATOMIC(int)
-__TBB_DECL_ATOMIC(unsigned short)
-__TBB_DECL_ATOMIC(short)
-__TBB_DECL_ATOMIC(char)
-__TBB_DECL_ATOMIC(signed char)
-__TBB_DECL_ATOMIC(unsigned char)
+
+__DRIZZLE_DECL_ATOMIC(long)
+__DRIZZLE_DECL_ATOMIC(unsigned long)
+__DRIZZLE_DECL_ATOMIC(unsigned int)
+__DRIZZLE_DECL_ATOMIC(int)
+__DRIZZLE_DECL_ATOMIC(unsigned short)
+__DRIZZLE_DECL_ATOMIC(short)
+__DRIZZLE_DECL_ATOMIC(char)
+__DRIZZLE_DECL_ATOMIC(signed char)
+__DRIZZLE_DECL_ATOMIC(unsigned char)
+__DRIZZLE_DECL_ATOMIC(bool)
+
+/* 32-bit platforms don't have a GCC atomic operation for 64-bit types,
+ * so we'll use pthread locks to handler 64-bit types on that platforms
+ */
+#  if SIZEOF_SIZE_T >= SIZEOF_LONG_LONG
+__DRIZZLE_DECL_ATOMIC(long long)
+__DRIZZLE_DECL_ATOMIC(unsigned long long)
+#  else
+#   define __DRIZZLE_DECL_ATOMIC64(T)                                   \
+  template<> struct atomic<T>                                           \
+  : internal::atomic_impl<T,T,internal::pthread_traits<T,T> > {         \
+    atomic<T>()                                                         \
+      : internal::atomic_impl<T,T,internal::pthread_traits<T,T> >() {}  \
+    T operator=( T rhs ) { return store_with_release(rhs); }            \
+  };
+__DRIZZLE_DECL_ATOMIC64(long long)
+__DRIZZLE_DECL_ATOMIC64(unsigned long long)
+#  endif
 
 }
-#endif /* defined(HAVE_LIBTBB) */
+# endif /* defined(HAVE_LIBTBB) */
 
 #endif /* DRIZZLED_ATOMIC_H */

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2009-03-25 22:03:13 +0000
+++ drizzled/drizzled.cc	2009-03-30 18:17:18 +0000
@@ -425,7 +425,7 @@
   Number of currently active user connections. The variable is protected by
   LOCK_thread_count.
 */
-tbb::atomic<uint32_t> connection_count;
+drizzled::atomic<uint32_t> connection_count;
 
 /* Function declarations */
 

=== modified file 'drizzled/query_id.h'
--- drizzled/query_id.h	2009-03-23 00:03:45 +0000
+++ drizzled/query_id.h	2009-03-30 18:17:18 +0000
@@ -39,7 +39,7 @@
   query_id_t next();
 
 private:
-  tbb::atomic<uint64_t> the_query_id;
+  drizzled::atomic<uint64_t> the_query_id;
 
   Query_id();
   Query_id(Query_id const&);

=== modified file 'plugin/multi_thread/multi_thread.cc'
--- plugin/multi_thread/multi_thread.cc	2009-03-22 08:32:24 +0000
+++ plugin/multi_thread/multi_thread.cc	2009-03-30 18:17:18 +0000
@@ -30,7 +30,7 @@
 
 class Multi_thread_scheduler: public Scheduler
 {
-  tbb::atomic<uint32_t> thread_count;
+  drizzled::atomic<uint32_t> thread_count;
   pthread_attr_t multi_thread_attrib;
 
 public:

